@@ -94,6 +94,7 @@ def preprocess(
         extractor_keywords = []
         injector_keywords = []
         field_keywords = []
+        smry = None
 
     def get_ecl(data):
         import opm.io
@@ -186,6 +187,7 @@ def preprocess(
     return {
         "phases": preprocess_phases(ecldeck),
         "start": preprocess_start(ecldeck),
+        "timestep": preprocess_timestep(smry),
         "endscale": find_keyword(ecldeck, "ENDSCALE"),
         "multout": find_keyword(ecldeck, "MULTOUT"),
         "dimens": preprocess_dimens(ecldeck),
@@ -207,6 +209,17 @@ def preprocess_start(ecldeck):
         return False
 
 
+def preprocess_timestep(smry):
+    from datetime import timedelta
+
+    try:
+        data = smry["TIMESTEP"]
+        unit = data.unit.lower()
+        return timedelta(**{unit: int(data[0].value)})
+    except Exception:
+        return None
+
+
 def preprocess_phases(ecldeck):
     return {
         "gas": find_keyword(ecldeck, "GAS"),
